[llvm-commits] CVS: llvm/include/llvm/CodeGen/CallingConvLower.h

Chris Lattner sabre at nondot.org
Tue Feb 27 23:09:59 PST 2007



Changes in directory llvm/include/llvm/CodeGen:

CallingConvLower.h updated: 1.3 -> 1.4
---
Log message:

add methods for analysis of call results and return nodes.


---
Diffs of the changes:  (+11 -3)

 CallingConvLower.h |   14 +++++++++++---
 1 files changed, 11 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/CodeGen/CallingConvLower.h
diff -u llvm/include/llvm/CodeGen/CallingConvLower.h:1.3 llvm/include/llvm/CodeGen/CallingConvLower.h:1.4
--- llvm/include/llvm/CodeGen/CallingConvLower.h:1.3	Wed Feb 28 00:56:37 2007
+++ llvm/include/llvm/CodeGen/CallingConvLower.h	Wed Feb 28 01:09:40 2007
@@ -130,13 +130,21 @@
     return UsedRegs[Reg/32] & (1 << (Reg&31));
   }
   
+  /// AnalyzeFormalArguments - Analyze an ISD::FORMAL_ARGUMENTS node,
+  /// incorporating info about the formals into this state.
+  void AnalyzeFormalArguments(SDNode *TheArgs, CCAssignFn Fn);
+  
+  /// AnalyzeReturn - Analyze the returned values of an ISD::RET node,
+  /// incorporating info about the result values into this state.
+  void AnalyzeReturn(SDNode *TheRet, CCAssignFn Fn);
+  
   /// AnalyzeCallOperands - Analyze an ISD::CALL node, incorporating info
   /// about the passed values into this state.
   void AnalyzeCallOperands(SDNode *TheCall, CCAssignFn Fn);
 
-  /// AnalyzeFormalArguments - Analyze an ISD::FORMAL_ARGUMENTS node,
-  /// incorporating info about the formals into this state.
-  void AnalyzeFormalArguments(SDNode *TheArgs, CCAssignFn Fn);
+  /// AnalyzeCallResult - Analyze the return values of an ISD::CALL node,
+  /// incorporating info about the passed values into this state.
+  void AnalyzeCallResult(SDNode *TheCall, CCAssignFn Fn);
   
 
   /// getFirstUnallocated - Return the first unallocated register in the set, or






More information about the llvm-commits mailing list